@@ -21,7 +21,7 @@
 
 =head1 NAME
 
-Sys::Virt::Error - error object for libvirt APIs
+Sys::Virt::Error - Error object for libvirt APIs
 
 =head1 DESCRIPTION
 
@@ -54,7 +54,7 @@ sub stringify {
     return "libvirt error code: " . $self->{code} . ", message: " . $self->{message} . ($self->{message} =~ /\n$/ ? "" : "\n");
 }
 
-=item my $code = $err->level
+=item my $level = $err->level
 
 Return the raw error level represented by this error. One of the
 ERROR LEVEL CONSTANTS
@@ -382,6 +382,50 @@ The polkit authentication / authorization APIs
 
 The thread helper utils
 
+=item Sys::Virt::Error::FROM_ADMIN
+
+The administrative service
+
+=item Sys::Virt::Error::FROM_LOGGING
+
+The logging service
+
+=item Sys::Virt::Error::FROM_XENXL
+
+The Xen XL driver
+
+=item Sys::Virt::Error::FROM_PERF
+
+The performance events subsystem
+
+=item Sys::Virt::Error::FROM_LIBSSH
+
+The libSSH socket client
+
+=item Sys::Virt::Error::FROM_RESCTRL
+
+The resource control subsystem
+
+=item Sys::Virt::Error::FROM_FIREWALLD
+
+The firewalld service
+
+=item Sys::Virt::Error::FROM_DOMAIN_CHECKPOINT
+
+The domain checkpoint
+
+=item Sys::Virt::Error::FROM_TPM
+
+The TPM subsystem
+
+=item Sys::Virt::Error::FROM_BPF
+
+The BPF subsystem
+
+=item Sys::Virt::Error::FROM_CH
+
+The Cloud Hypervisor driver
+
 =back
 
 =head2 ERROR CODE CONSTANTS
@@ -393,7 +437,7 @@ handled separately from generic error handling.
 
 =item Sys::Virt::Error::ERR_AUTH_FAILED
 
-Authentication falure when connecting to a driver
+Authentication failure when connecting to a driver
 
 =item Sys::Virt::Error::ERR_CALL_FAILED
 
@@ -505,7 +549,7 @@ Missing root device information in domain configuration
 
 =item Sys::Virt::Error::ERR_NO_SECURITY_MODEL
 
-Missing security model information in domain configuratio
+Missing security model information in domain configuration
 
 =item Sys::Virt::Error::ERR_NO_SOURCE
 
@@ -633,7 +677,7 @@ There are multiple interfaces with the requested MAC address
 
 =item Sys::Virt::Error::ERR_BUILD_FIREWALL
 
-The firwall could not be constructed
+The firewall could not be constructed
 
 =item Sys::Virt::Error::WAR_NO_NWFILTER
 
@@ -764,6 +808,90 @@ The CPUs are not compatible
 
 The XML document does not comply with the XML schema
 
+=item Sys::Virt::Error::ERR_MIGRATE_FINISH_OK
+
+Migration finished but expected to return NULL domain.
+
+=item Sys::Virt::Error::ERR_AUTH_UNAVAILABLE
+
+Authentication services were not available
+
+=item Sys::Virt::Error::ERR_NO_SERVER
+
+Libvirt server was not found
+
+=item Sys::Virt::Error::ERR_NO_CLIENT
+
+Libvirt client was not found
+
+=item Sys::Virt::Error::ERR_AGENT_UNSYNCED
+
+Libvirt guest agent replies with wrong id to guest-sync command
+
+=item Sys::Virt::Error::ERR_LIBSSH
+
+The libSSH operation failed
+
+=item Sys::Virt::Error::ERR_DEVICE_MISSING
+
+Libvirt fail to find the desired device.
+
+=item Sys::Virt::Error::ERR_INVALID_NWFILTER_BINDING
+
+Invalid nwfilter binding
+
+=item Sys::Virt::Error::ERR_NO_NWFILTER_BINDING
+
+No nwfilter binding
+
+=item Sys::Virt::Error::ERR_INVALID_DOMAIN_CHECKPOINT
+
+Invalid domain checkpoint
+
+=item Sys::Virt::Error::ERR_NO_DOMAIN_BACKUP
+
+Domain checkpoint not found
+
+=item Sys::Virt::Error::ERR_NO_DOMAIN_CHECKPOINT
+
+Domain backup job id not found
+
+=item Sys::Virt::Error::ERR_NO_NETWORK_PORT
+
+No matching network port
+
+=item Sys::Virt::Error::ERR_INVALID_NETWORK_PORT
+
+Invalid network port object
+
+=item Sys::Virt::Error::ERR_NETWORK_PORT_EXIST
+
+Network port already exists
+
+=item Sys::Virt::Error::ERR_NO_HOSTNAME
+
+No domain hostname found
+
+=item Sys::Virt::Error::ERR_CHECKPOINT_INCONSISTENT
+
+The checkpoint is inconsistent
+
+=item Sys::Virt::Error::ERR_MULTIPLE_DOMAINS
+
+More than one matching domain found
+
+=item Sys::Virt::Error::ERR_NO_NETWORK_METADATA
+
+The requested metadata does not exist
+
+=item Sys::Virt::Error::ERR_AGENT_COMMAND_TIMEOUT
+
+Guest agent didn't respond to a non-sync command within timeout
+
+=item Sys::Virt::Error::ERR_AGENT_COMMAND_FAILED
+
+Guest agent responded with failure to a command
+
 =back
 
 =head1 AUTHORS
